@@ -15,9 +15,9 @@ import os.path
 import sys
 import traceback
 
+import molsystem
 import reference_handler
 import seamm
-from seamm_util import to_mmcif, to_cif
 import seamm_util.printing as printing
 from seamm_util.printing import FormattedText as __  # noqa: F401
 
@@ -37,9 +37,16 @@ class ExecFlowchart(object):
         if not self.flowchart:
             raise RuntimeError('There is no flowchart to run!')
 
+        # Create the global context
         logger.debug('Creating global variables space')
         seamm.flowchart_variables = seamm.Variables()
 
+        # Create the system handler and default system in the global context
+        systems = molsystem.Systems()
+        system = systems.create_system('seamm')
+        seamm.flowchart_variables.set_variable('_systems', systems)
+        seamm.flowchart_variables.set_variable('_system', system)
+
         self.flowchart.root_directory = root
 
         # Correctly number the nodes
@@ -110,25 +117,37 @@ class ExecFlowchart(object):
                 raise
 
         # Write the final structure
-        if seamm.data.structure is not None:
-            system = seamm.data.structure
+        system = seamm.flowchart_variables.get_variable('_system')
+        if system.n_atoms() > 0:
             # MMCIF file has bonds
             filename = os.path.join(
                 self.flowchart.root_directory, 'final_structure.mmcif'
             )
-            with open(filename, 'w') as fd:
-                print(to_mmcif(system), file=fd)
-            job.job(
-                "\nWrote the final structure to 'final_structure.mmcif' for "
-                'viewing.'
-            )
+            text = None
+            try:
+                text = system.to_mmcif_text()
+            except Exception:
+                message = (
+                    'Error creating the final mmcif file\n\n' +
+                    traceback.format_exc()
+                )
+                print(message)
+                logger.critical(message)
+
+            if text is not None:
+                with open(filename, 'w') as fd:
+                    print(text, file=fd)
+                job.job(
+                    "\nWrote the final structure to 'final_structure.mmcif' "
+                    'for viewing.'
+                )
             # CIF file has cell
-            if system['periodicity'] == 3:
+            if system.periodicity == 3:
                 filename = os.path.join(
                     self.flowchart.root_directory, 'final_structure.cif'
                 )
                 with open(filename, 'w') as fd:
-                    print(to_cif(seamm.data.structure), file=fd)
+                    print(system.to_cif_text(), file=fd)
                 job.job(
                     "\nWrote the final structure to 'final_structure.cif' for "
                     'viewing.'
